@@ -24,7 +24,7 @@ from os.path import dirname, exists, join
 from PyQt5.QtCore import QByteArray, QLocale, QSettings, QStandardPaths
 from PyQt5.QtGui import QFont
 
-app_version = "7.0.0"
+app_version = "7.0.4"
 
 settings = QSettings('ReText project', 'ReText')
 
@@ -162,7 +162,9 @@ class ReTextSettings(object):
 	def __getattribute__(self, option):
 		value = object.__getattribute__(self, option)
 		# Choose a font just-in-time, because when the settings are
-		# loaded it is too early to work on Windows
+		# loaded it is too early to work.
+		if option == 'font' and not value.family():
+			value = QFont()
 		if option == 'editorFont' and not value.family():
 			value = chooseMonospaceFont()
 		return value
