@@ -135,12 +135,12 @@
 <context>
     <name>ReTextEdit</name>
     <message>
-        <location filename="editor.py" line="295"/>
+        <location filename="editor.py" line="292"/>
         <source>Save image</source>
         <translation>Speicher als Bild</translation>
     </message>
     <message>
-        <location filename="editor.py" line="295"/>
+        <location filename="editor.py" line="292"/>
         <source>Images (*.png *.jpg)</source>
         <translation>Bild (*.png *.jpg)</translation>
     </message>
@@ -514,7 +514,7 @@
     <message>
         <location filename="window.py" line="919"/>
         <source>HTML files (*.html *.htm)</source>
-        <translation>HTML-Dateien (*.html, *.htm)</translation>
+        <translation>HTML-Dateien (*.html *.htm)</translation>
     </message>
     <message>
         <location filename="window.py" line="940"/>
