@@ -5,13 +5,18 @@
     <message>
         <location filename="config.py" line="67"/>
         <source>Behavior</source>
-        <translation>Режим</translation>
+        <translation>Поведінка</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Automatically save documents</source>
         <translation>Автоматично зберігати документи</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>Автоматично відкривати останні документи при запуску</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
@@ -55,7 +60,7 @@
     <message>
         <location filename="config.py" line="67"/>
         <source>Tab key inserts spaces</source>
-        <translation>Поставити пробіл клявішею Tab</translation>
+        <translation>Клавіша Tab вставляє пробіли</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
@@ -87,11 +92,6 @@
         <source>Help</source>
         <translation>Довідка</translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Automatically open last documents on startup</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -193,7 +193,7 @@
     <message>
         <location filename="window.py" line="1096"/>
         <source>Reload</source>
-        <translation>Завантажити заново</translation>
+        <translation>Перезавантажити</translation>
     </message>
     <message>
         <location filename="window.py" line="105"/>
@@ -255,6 +255,11 @@
         <source>Live preview</source>
         <translation>Одночасний перегляд</translation>
     </message>
+    <message>
+        <location filename="window.py" line="144"/>
+        <source>Table editing mode</source>
+        <translation>Режим редагування таблиць</translation>
+    </message>
     <message>
         <location filename="window.py" line="148"/>
         <source>FakeVim mode</source>
@@ -268,7 +273,7 @@
     <message>
         <location filename="window.py" line="588"/>
         <source>Preferences</source>
-        <translation>Вибране</translation>
+        <translation>Налаштування</translation>
     </message>
     <message>
         <location filename="window.py" line="163"/>
@@ -315,6 +320,11 @@
         <source>Use WebKit renderer</source>
         <translation>Використовувати WebKit</translation>
     </message>
+    <message>
+        <location filename="window.py" line="191"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation>Використовувати WebEngine (Chromium)</translation>
+    </message>
     <message>
         <location filename="window.py" line="196"/>
         <source>Show directory</source>
@@ -330,6 +340,16 @@
         <source>Previous</source>
         <translation>Попереднє</translation>
     </message>
+    <message>
+        <location filename="window.py" line="201"/>
+        <source>Replace</source>
+        <translation>Замінити</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="203"/>
+        <source>Replace all</source>
+        <translation>Замінити все</translation>
+    </message>
     <message>
         <location filename="window.py" line="207"/>
         <source>Close</source>
@@ -353,12 +373,12 @@
     <message>
         <location filename="window.py" line="229"/>
         <source>Bold</source>
-        <translation>Потовщення</translation>
+        <translation>Жирний</translation>
     </message>
     <message>
         <location filename="window.py" line="231"/>
         <source>Italic</source>
-        <translation>Нахил</translation>
+        <translation>Курсив</translation>
     </message>
     <message>
         <location filename="window.py" line="233"/>
@@ -415,6 +435,11 @@
         <source>Search</source>
         <translation>Пошук</translation>
     </message>
+    <message>
+        <location filename="window.py" line="342"/>
+        <source>Replace with</source>
+        <translation>Замінити на</translation>
+    </message>
     <message>
         <location filename="window.py" line="344"/>
         <source>Case sensitively</source>
@@ -466,6 +491,11 @@
         <source>Save file</source>
         <translation>Зберегти файл</translation>
     </message>
+    <message>
+        <location filename="window.py" line="860"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation>Неможливо зберегти файл відкритий в іншій вкладці!</translation>
+    </message>
     <message>
         <location filename="window.py" line="884"/>
         <source>Cannot save to file because it is read-only!</source>
@@ -530,8 +560,8 @@
         <location filename="window.py" line="1080"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
-        <translation>Цей файл був вилучений іншим користувачем.
-Будь ласка, переконайтеся перед виходом, що Ви зберегли файл.</translation>
+        <translation>Цей файл був видалений іншим додатком.
+Будь ласка, переконайтеся перед виходом, що ви зберегли файл.</translation>
     </message>
     <message>
         <location filename="window.py" line="1087"/>
@@ -539,13 +569,13 @@ Please make sure you save the file before exit.</source>
 Do you want to reload the file (this will discard all your changes)?
 </source>
         <translation>Цей документ був змінений іншим застосунком.
-Чи волієте Ви завантажити файл поновій (це скасує усі Ваші зміни)?
+Бажаєте перезавантажити файл і втратити незбережені зміни?
 </translation>
     </message>
     <message>
         <location filename="window.py" line="1092"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
-        <translation>Якщо Ви вирішите не перезавантажувати файл, режим автоматичного збереження буде вимкнено для цього сеансу з метою попередження втрати даних.</translation>
+        <translation>Якщо ви вирішите не перезавантажувати файл, режим автоматичного збереження буде вимкнено для цього сеансу з метою попередження втрати даних.</translation>
     </message>
     <message>
         <location filename="window.py" line="1116"/>
@@ -590,35 +620,5 @@ Do you want to save your changes?</source>
         <source>reStructuredText syntax</source>
         <translation>Синтаксис reStructuredText</translation>
     </message>
-    <message>
-        <location filename="window.py" line="144"/>
-        <source>Table editing mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="201"/>
-        <source>Replace</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="203"/>
-        <source>Replace all</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="342"/>
-        <source>Replace with</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="860"/>
-        <source>Cannot save to file which is open in another tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Use WebEngine (Chromium) renderer</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 </TS>
